@@ -8,14 +8,15 @@ use tracing_layer_slack::{EventFilters, SlackLayer};
 pub async fn handler() {
     info!(
         the_only_field = "this is the only field you should see",
-        password = "hunter2"
+        password = "hunter2",
+        access_token = "sifjsadfjasd89fuas8d9f"
     );
 }
 
 #[tokio::main]
 async fn main() {
     let targets_to_filter: EventFilters = Regex::new("exclude_fields_from_messages").unwrap().into();
-    let fields_to_exclude = vec![Regex::new("password").unwrap()];
+    let fields_to_exclude = vec![Regex::new(".*token.*").unwrap(), Regex::new(".*password.*").unwrap()];
     let (slack_layer, mut background_worker) = SlackLayer::builder(targets_to_filter)
         .field_exclusion_filters(fields_to_exclude)
         .build();
